/*
 * Event management functions
 *
 * Requires:
 *  - appuntat.global.js
 *  - jquery.dataTables.js
 *  - jquery.ui.min
 */

// Loads the event data
// Requires:
// - the progress moda div "mdlProgress"
function emLoadEventData( eventId, callBack ){
    $.ajax({
        url: ctBackendRootURL + "/getEvent",
        data: { id: eventId }
    }).then( callBack );
}

// Sets the initial data
function emLoadNewEventData( urlParams ){
    if( urlParams.requesterProfileType == ctProfileTypeSportist ){
        emAddInvitedSportist( urlParams.requesterProfileId, urlParams.requesterProfileName );
    }else if( urlParams.requesterProfileType == ctProfileTypeLocation ){
        $('#hdnLocationId').val( urlParams.requesterProfileId );
        $('#fldLocationName').text( urlParams.requesterProfileName );        
    }else{
        console.error( "Invalid requester profile type: " + requesterProfileType );
    }
}

// Fills the info fields with the loaded user data in VIEW mode
var emShowDataInViewMode = function( response ){
    $('#fldEventName').text( response.result.name );    
    $('#fldEventDate').text( response.result.date );
    if( response.result.location ){
        $('#fldLocationName').text( response.result.location.name );
        $('#hdnLocationId').val( response.result.location.id );
    }
    pmLoadPicture( response.result.pictureId , ctProfileTypeEvent );
    if( response.result.manager.id != gfGetGlobalValue( ctKeyUserId ) ){
        $('#divEdit').addClass('hide');
        $('#divDelete').addClass('hide');
    }    
}

// Fills the info fields with the loaded user data in EDIT mode
var emShowDataInEditMode = function( response ){
    $('#txtEventName').val( response.result.name );
    var parsedDate = gfParseDateTime( response.result.date );
    if( parsedDate != undefined ){
        $('#txtEventDate').val( parsedDate.day + "/" + parsedDate.month + "/" + parsedDate.year );
        $('#selEventHour').val( parsedDate.hour );
        $('#selEventMinute').val( parsedDate.minute );        
    }
    if( response.result.location ){
        $('#fldLocationName').text( response.result.location.name );
        $('#hdnLocationId').val( response.result.location.id );
    }
    emLoadInvitedSportistsForEditting( response.result.id );
    pmLoadPicture( response.result.pictureId , ctProfileTypeEvent );
}

// Loads the list of invited sportists
function emLoadInvitedSportistsForEditting( eventId ){
    var requestUrl = ctBackendRootURL + "/listSportist";
    var requestParams = {
        profileType: ctProfileTypeEvent,
        profileId: eventId,
        draw:0,
        start:0,
        length:0
    }
    $.get( requestUrl , requestParams , function( response ){
       emSetInvitedSportistsTableElemsForEditting( response.data );        
    });
}

// Sets the elems of the invited sportists table
// Params:
//    - the invited sportists (arrays of Sportist)
// Requires:
//    - the table 'tblInvitedSportistList'
function emSetInvitedSportistsTableElemsForEditting( sportists ){
    var tBody = document.getElementById("tblInvitedSportistList").appendChild(document.createElement('tbody'));
    for(sportistIdx in sportists){        
        emAddElemToTableBody( tBody, sportists[sportistIdx].id, sportists[sportistIdx].name );
    }
    document.getElementById("tblInvitedSportistList").tHead.rows[0].cells[0].className = "hide";
}

// Removes the specified element from the table of invited sportists
// Requires:
//    - the table 'tblInvitedSportistList'
function emRemoveInvitedSportist( sportistIdx ){
    document.getElementById("tblInvitedSportistList").tBodies[0].deleteRow( sportistIdx );
}

// Add an element to the table of invited sportists
// Requires:
//    - the table 'tblInvitedSportistList'
function emAddInvitedSportist( sportistId, sportistName ){
    $('#tblInvitedSportistList').removeClass("hide");
    // if id already in table, do nothing
    invitedSportists = emGetInvitedSportistsTableElems().split(';');
    for(sportistIdx in invitedSportists){
        if( sportistId == invitedSportists[ sportistIdx ] ) return;
    }
    // else, add
    var targetTableBody = document.getElementById("tblInvitedSportistList").tBodies[0];
    if(targetTableBody == undefined){
        targetTableBody = document.getElementById("tblInvitedSportistList").appendChild(document.createElement('tbody'));
        document.getElementById("tblInvitedSportistList").tHead.rows[0].cells[0].className = "hide";
    }
    emAddElemToTableBody( targetTableBody, sportistId, sportistName );
}

// Adds an elem to the given table body
function emAddElemToTableBody( targetTableBody, elemId, elemName ){
    var newRowIdx = targetTableBody.rows.length;
    var row = targetTableBody.insertRow( newRowIdx );
    var cellSportistId = row.insertCell(0);
    cellSportistId.innerHTML = elemId;
    cellSportistId.className = "hide";
    var cellSportistName = row.insertCell(1);
    cellSportistName.innerHTML = elemName;
    var cellAction = row.insertCell(2);
    cellAction.innerHTML = '<a onclick="emRemoveInvitedSportist('+newRowIdx+')">Eliminar</a>';
}

// Gets the list of elems in the equipment table
// Returns:
//    - a ;-tokenized string with all the sportist ids in the table (id1;id2;...)
// Requires:
//    - the table 'tblInvitedSportistList'
function emGetInvitedSportistsTableElems(){
    var sportists = "";
    var tBody = document.getElementById("tblInvitedSportistList").getElementsByTagName('tbody')[0];
    if( tBody != undefined && tBody.rows != undefined){
        for(var i=0; i<tBody.rows.length; i++){
            if(i>0) sportists += ";";
            sportists += tBody.rows[i].cells[0].innerHTML;
        }
    }
    return sportists;
}

// Saves the changes done to the event
function emUpdateEvent( eventId ){
    $( "#divProgressBar" ).progressbar({ value: 25 });
    var formAction = ctBackendRootURL + "/updateEvent";
    var formData = {
        name: $('#txtEventName').val(),
        date: $('#txtEventDate').val() + " " + $('#selEventHour').val() + ":" + $('#selEventMinute').val(),
        locationId: $('#hdnLocationId').val(),
        sportists: emGetInvitedSportistsTableElems()
    }
    if( eventId == null ){
        // creating new
        formData.managerId = gfGetGlobalValue( ctKeyUserId );
    }else{
        // editing existing
        formData.id = eventId;
    }
    $.post( formAction, formData, emUpdateEventCallback );
}
var emUpdateEventCallback = function( response ){
    $( "#divProgressBar" ).progressbar({ value: 75 });
    if($.isEmptyObject( response.result )){
        gfShowMessage( "No s'ha pogut actualitzar el perfil: " + response.errorMessage, true );
    }else{
        gotoProfileDetailPage( response.result.id, ctProfileTypeEvent );
    }
};

// Deletes the specified event
function emDeleteEvent( eventId ){
    $( "#divProgressBar" ).progressbar({ value: 25 });
    var url = ctBackendRootURL + "/deleteEvent";
    var data = { "id": eventId };
    $.get( url, data, emDeleteEventCallback );
}
var emDeleteEventCallback = function( response ){
    if( ! $.isEmptyObject( response.errorMessage ) ){
        gfShowMessage( "No s'ha pogut eliminar l'esdeveniment: " + response.errorMessage, true );
    }else{
        pmGotoProfileHome();
    }
};

// Invites the given sportist to the given event
// Params
//    - sportistId: The sportist to invite
//    - eventId: The event to be invited to
function emInviteSportist( eventId, sportistId ){
    $( "#divProgressBar" ).progressbar({ value: 25 });
    var url = ctBackendRootURL + "/inviteSportist";
    var data = { "eventId": eventId, "sportistId": sportistId };
    $.get( url, data, emInviteSportistCallback );
}
var emInviteSportistCallback = function(response){
    if( ! $.isEmptyObject( response.errorMessage ) ){
        gfShowMessage( "No s'ha pogut convidar a l'esportista: " + response.errorMessage, true );
    }else{
        pmGotoProfileHome();
    }
}

// Requests the given location to host the given event
// Params
//    - locationId: The location to request to
//    - eventId: The event to be hosted
function emRequestLocation( eventId, locationId ){
    $( "#divProgressBar" ).progressbar({ value: 25 });
    var url = ctBackendRootURL + "/requestLocation";
    var data = { "eventId": eventId, "locationId": locationId };
    $.get( url, data, emRequestLocationCallback );
}
var emRequestLocationCallback = function(response){
    if( ! $.isEmptyObject( response.errorMessage ) ){
        gfShowMessage( "No s'ha pogut solicitar la instalacio: " + response.errorMessage, true );
    }else{
        pmGotoProfileHome();
    }
}