/*
 * Location management functions
 *
 * Requires:
 *  - appuntat.global.js
 *  - jquery.dataTables.js
 *  - jquery.ui.js
 */

// Loads the location data
// Requires:
// - the progress moda div "mdlProgress"
function lmLoadLocationData( locationId, callBack ){
    $.ajax({
        url: ctBackendRootURL + "/getLocation",
        data: { id: locationId }
    }).then( callBack );
}

// Fills the info fields with the loaded user data in VIEW mode
var lmShowDataInViewMode = function( response ){
    $('#fldLocationName').text(response.result.name);
    $('#fldLocationAddress').text(response.result.address);
    lmSetEquipmentTableElems( response.result.equipment , false );
    pmLoadPicture( response.result.pictureId , ctProfileTypeLocation );
}

// Fills the info fields with the loaded user data in EDIT mode
var lmShowDataInEditMode = function( response ){    
    $('#txtLocationName').val( response.result.name );
    $('#txtLocationAddress').val( response.result.address );
    lmSetEquipmentTableElems( response.result.equipment , true );
    pmLoadPicture( response.result.pictureId , ctProfileTypeLocation );
}

// Sets the elems of the equipment table
// Params:
//    - the equipment elems (arrays of String)
// Requires:
//    - the table 'tblEquipment'
function lmSetEquipmentTableElems( equipmentElems , addDelLink ){    
    var tBody = document.getElementById("tblEquipment").appendChild(document.createElement('tbody'));
    for(equipmentIdx in equipmentElems){
        var row = tBody.insertRow( equipmentIdx );
        var cellEquipment = row.insertCell(0);
        cellEquipment.innerHTML = equipmentElems[equipmentIdx];
        if( addDelLink ){
            var cellAction = row.insertCell(1);
            cellAction.innerHTML = '<a href="#" onclick="lmRemoveEquipmentElem('+equipmentIdx+')">Eliminar</a>';
        }
    }
}

// Removes the selected equipment
// Params:
//    - elemIdx: the index of the teble element to remove
// Requires:
//    - the table 'tblEquipment'
function lmRemoveEquipmentElem( elemIdx ){
    document.getElementById("tblEquipment").tBodies[0].deleteRow( elemIdx );
}

// Adds a new equipment to the equipment table
// Params:
//    - equipmentName: the name of the table element to add
// Requires:
//    - the table 'tblEquipment'
function lmAddEquipmentElem( equipmentName ){    
    var tblEquipment = document.getElementById("tblEquipment");
    if( tblEquipment.tBodies == undefined ) tblEquipment.appendChild(document.createElement('tbody'));
    var elemIdx = 0;
    if( tblEquipment.tBodies[0].rows != undefined ) elemIdx = tblEquipment.tBodies[0].rows.length;
    var row = tblEquipment.tBodies[0].insertRow( elemIdx );
    var cellEquipment = row.insertCell(0);
    cellEquipment.innerHTML = equipmentName;
    var cellAction = row.insertCell(1);
    cellAction.innerHTML = '<a onclick="lmRemoveEquipmentElem('+elemIdx+')">Eliminar</a>';
}

// Sets the visibility of the location specific elements
function lmSetLocationOptionsVisibility(){
    // hide everything
    $('#divEdit').addClass("hide"); // link to edit the location profile
    $('#divRequest').addClass("hide"); // link to ask the location manager to perform event there
    $('#divSearch').addClass("hide"); // link to search page
    // show only what's allowed
    if( gfGetGlobalValue( ctKeyProfileType ) == ctProfileTypeSportist ){
        // profile opened by a sportist
        $('#divRequest').removeClass("hide");
    }else{
        // profile opened by a location
        var urlParams = gfQueryStringToJSON( location.search.slice(1) );
        if( pmProfileViewerIsItsManager() ){
            // logged sportist is the manager of the profile being shown
            $('#divEdit').removeClass("hide");
            $('#divSearch').removeClass("hide");
        }
    }
}

// Gets the list of elems in the equipment table
// Returns:
//    - a ;-tokenized string with all the elems in the table (elem1;elem2;...)
// Requires:
//    - the table 'tblEquipment'
function lmGetEquipmentTableElems(){
    var equipment = "";
    var tBody = document.getElementById("tblEquipment").getElementsByTagName('tbody')[0];
    if( tBody != undefined && tBody.rows != undefined){
        for(var i=0; i<tBody.rows.length; i++){
            if(i>0) equipment += ";";
            equipment += tBody.rows[i].cells[0].innerHTML;
        }
    }
    return equipment;
}

// Saves the changes done to the location
function lmUpdateLocation(){
    $( "#divProgressBar" ).progressbar({ value: 25 });
    var profileId = gfGetGlobalValue( ctKeyProfileId );
    var formAction = ctBackendRootURL + "/updateLocation";
    var formData = {
        id: profileId,
        name: $('#txtLocationName').val(),
        address: $('#txtLocationAddress').val(),
        equipment: lmGetEquipmentTableElems()
    }
    $.post( formAction, formData, lmUpdateLocationCallback );
}
var lmUpdateLocationCallback = function( response ){
    $( "#divProgressBar" ).progressbar({ value: 75 });
    if($.isEmptyObject( response.result )){
        gfShowMessage( "No s'ha pogut actualitzar el perfil: " + response.errorMessage, true );
    }else{
        gotoProfileDetailPage( gfGetGlobalValue( ctKeyProfileId ), ctProfileTypeLocation )
    }
};